GeoLocation class
Helper class for GeoLocation points
Constructors
- GeoLocation({required double longitude, required double latitude, required String member})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited