hLen method

Future<int> hLen(
  1. String key
)

HLEN key

Returns the number of fields contained in the hash stored at key.

Returns the number of fields in the hash, or 0 when key does not exist.

Implementation

Future<int> hLen(String key) async {
  final cmd = <String>['HLEN', key];
  return executeInt(cmd);
}