onBadCertificate property
Callback to handle bad certificates (e.g., self-signed certificates in
dev).
Returns true to allow the connection, false to abort.
Implementation
final bool Function(X509Certificate)? onBadCertificate;
Callback to handle bad certificates (e.g., self-signed certificates in
dev).
Returns true to allow the connection, false to abort.
final bool Function(X509Certificate)? onBadCertificate;